% Solve nonlinear Helmholtz equation

% NLH parameters
k0=8;
epsilon=.16;

% Discretization (finite difference) initialization
N=2001;
x = linspace(0,10,N);
h = x(2)-x(1);

% initial guess is soln to linear prob (i.e. soln when eps=0
u = cos(k0*x') + 1i * sin(k0*x');

for j=1:500  
    
    %  save last solution 
    uold = u;
        
    % Get u_j = g(u_{j-1}) by solving linearized system
        % build FD matrix
        e = ones(N,1);
        d = -2 + h^2 * k0^2 *(1 + epsilon .* (abs(u)).^2) ;
        A = spdiags([e d e],[-1 0 1],N,N);
        b = zeros(N,1);
        % boundary conditions; alter 1st and last eqns
        A(1,1)= -3 + 2*1i*h*k0;
        A(1,2)=4;
        A(1,3)=-1;
        b(1)=4*1i*k0*h;
        A(N,N)=3 - 2*1i*k0*h;
        A(N,N-1)=-4;
        A(N,N-2)=1;
        b(N)=0;    
        % linear solve
        u = A\b;
    
        % Calculate residual wj = || uj - u_{j-1}||
        w(j)=norm(u - uold);

        % check for convergence
        if w(j)<1e-8
            break
        end

end
    


figure
semilogy(w,'kx')
xlabel('k','FontSize',20)
ylabel('Residual','FontSize',20)
set(gca,'FontSize',20)
hold on





