function y = backwardEuler(func,t,y1)
% Solve the ODE y'=f(t,y) with initial condition y(t1)=y1 and return
% the function values as a vector.
% func is the function handle for f(t,y) and t is a vector
% of the times: [t1,t2,...,tn].

% N is the total number of points, initialize y to be the same
% size as t:
N = length(t);
y = zeros(N,1);

% initial condition
y(1)=y1;

% use BE to find y_i+1 
for i=1:length(y)-1
    % solve y(i+1) - y(i) + dt * f(t(i+1),y(i+1)) = 0
    % define an inline function where y(i+1) is independent variable
    ode_eqn = @(ynext) ynext - y(i) - ( t(i+1) - t(i) ) ...
                * feval(func,t(i+1),ynext);
    % solve w/ Matlab's 1d solver, guess y(i) is the solution
    y(i+1) = fzero(ode_eqn,y(i));
end

