function [U,x,t] = heat1d(a,b,T,uL,uR,uInit,N,M)

% solve the heat equation on [a,b]x[0,T], with boundary conditions
% u_L (at a) and u_R (at b), with initial condition uInit

% Discretize with N+1 points in space, and M+1 in time
x = linspace(a,b,N+1);
dx = x(2)-x(1);

t = linspace(0,T,M+1);
dt = t(2)-t(1);

% initialize solution matrix
U = zeros(N+1,M+1);

% Insert initial condition in first row of matrix
U(:,1) = uInit(x');

% Now we march through time.  Note the matrix is the same at each time
% step, so we can build it first.
e = ones(N-1,1);
r = dt/(dx^2);
A = spdiags([-r*e (1+2*r)*e -r*e], -1:1, N-1, N-1);

for m=2:M+1
    rhs = U(2:end-1,m-1);
    % boundary conditions affect first and last equation
    rhs(1) = rhs(1) + r*uL;
    rhs(end) = rhs(end) + r*uR;
    
    % solve the linear system for the values at time step m
    U(2:end-1,m)= A \ rhs;
    % add in the boundary values at time m
    U(1,m)=uL;
    U(N+1,m)=uR;
end

